Links
=====

Project Codes and Package
-------------------------

- Github_
- PyPI_

.. _Github: https://github.com/stephenhky/PyShortTextCategorization

.. _PyPI: https://pypi.org/project/shorttext/

Issues
------

To report bugs and issues, please go to Issues_.

.. _Issues: https://github.com/stephenhky/PyShortTextCategorization/issues

Gensim Incubator
----------------

Chinmaya Pancholi, a student in Indian Institute of Technology, Kharagpur, is supported
by Google Summer of Code (GSoC) project to support the open-source project for `gensim`.
Part of his project is to employ the wrapping ideas in `shorttext` to integrate `keras`,
`scikit-learn` and `gensim`.

Chinmaya's blog posts: `https://rare-technologies.com/author/chinmaya/
<https://rare-technologies.com/author/chinmaya/>`_

Chinmaya's proposal for GSoC: `https://github.com/numfocus/gsoc/blob/master/2017/proposals/Chinmaya_Pancholi.md
<https://github.com/numfocus/gsoc/blob/master/2017/proposals/Chinmaya_Pancholi.md>`_


Blog Entries
------------

"R or Python on Text Mining," *Everything About Data Analytics*, WordPress (2015). [`WordPress
<https://datawarrior.wordpress.com/2015/08/12/codienerd-1-r-or-python-on-text-mining>`_]

"Short Text Categorization using Deep Neural Networks and Word-Embedding Models," *Everything About Data Analytics*, WordPress (2015). [`WordPress
<https://datawarrior.wordpress.com/2016/10/12/short-text-categorization-using-deep-neural-networks-and-word-embedding-models/>`_]
(A code demonstration can be found in an early version of the Github repository for this package: `here
<https://github.com/stephenhky/PyShortTextCategorization/tree/b298d3ce7d06a9b4e0f7d32f27bab66064ba7afa>`_)

"Toying with Word2Vec," *Everything About Data Analytics*, WordPress (2015). [`WordPress
<https://datawarrior.wordpress.com/2015/10/25/codienerd-2-toying-with-word2vec/>`_]

"Probabilistic Theory of Word Embeddings: GloVe," *Everything About Data Analytics*, WordPress (2016). [`WordPress
<https://datawarrior.wordpress.com/2016/07/25/probabilistic-theory-of-word-embeddings-glove/>`_]

"Word-Embedding Algorithms," *Everything About Data Analytics*, WordPress (2016). [`WordPress
<https://datawarrior.wordpress.com/2016/05/15/word-embedding-algorithms/>`_]

"Python Package for Short Text Mining," *Everything About Data Analytics*, WordPress (2016). [`WordPress
<https://datawarrior.wordpress.com/2016/12/22/python-package-for-short-text-mining/>`_]

"Short Text Mining using Advanced Keras Layers and Maxent: shorttext 0.4.1," *Everything About Data Analytics*, WordPress (2017). [`WordPress
<https://datawarrior.wordpress.com/2017/07/30/short-text-mining-using-advanced-keras-layers-and-maxent-shorttext-0-4-1/>`_]

"Word Mover’s Distance as a Linear Programming Problem," *Everything About Data Analytics*, WordPress (2017). [`WordPress
<https://datawarrior.wordpress.com/2017/08/16/word-movers-distance-as-a-linear-programming-problem/>`_]

"Release of shorttext 0.5.4," *Everything About Data Analytics*, WordPress (2017). [`WordPress
<https://datawarrior.wordpress.com/2017/09/08/release-of-shorttext-0-5-4/>`_]

"Document-Term Matrix: Text Mining in R and Python," *Everything About Data Analytics*, WordPress (2018). [`WordPress
<https://datawarrior.wordpress.com/2018/01/22/document-term-matrix-text-mining-in-r-and-python/>`_]

"Package shorttext 1.0.0 Released," Medium (2018). [`Medium
<https://medium.com/@stephenhky/package-shorttext-1-0-0-released-ca3cb24d0ff3>`_]

Home: :doc:`index`